import { Component, OnInit } from "@angular/core";
import { Router } from "@angular/router";
import { Location } from "@angular/common";
import { Http, Request, RequestMethod } from "@angular/http";
import * as Utility from "utils/utils";
import { CouchbaseInstance } from "../../couchbase";
import "rxjs/Rx";

@Component({
    selector: "feed",
    templateUrl: "./components/feed/feed.component.html",
    styleUrls: ["./components/feed/feed.component.css"]
})
export class FeedComponent implements OnInit {

    private database: any;
    public feedList: Array<Object>;

    public constructor(private router: Router, private location: Location, private http: Http, private couchbaseInstance: CouchbaseInstance) {
        this.feedList = [];
        this.database = this.couchbaseInstance.getDatabase();
    }

    public ngOnInit() {
        this.location.subscribe((path) => {
            this.load();
        });
        this.load();
    }

    private load() {
        this.feedList = [];
        var rows = this.database.executeQuery("sources", {descending: false});
        for(let i = 0; i < rows.length; i++) {
            this.http.request(new Request({
                method: RequestMethod.Get,
                url: "https://query.yahooapis.com/v1/public/yql?q=select%20title%2C%20description%2C%20link%20from%20rss%20where%20url%3D%22" + rows[i].link + "%22&format=json&diagnostics=true&callback="
            }))
            .map(result => result.json())
            .subscribe((result) => {
                let items = result.query.results.item;
                for(let i = 0; i < items.length; i++) {
                    items[i].description = this.cleanText(items[i].description);
                    items[i].description = items[i].description.substring(0, items[i].description.indexOf("...") + 3);
                }
                this.feedList = this.feedList.concat(items);
            }, (error) => {
                console.log(error);
            });
        }
    }

    private cleanText(text: string) {
        let cleaned = text;
        cleaned = cleaned.replace(/(<([^>]+)>)/ig,"");
        cleaned = cleaned.replace(/&#8217;/gi, "\'");
        cleaned = cleaned.replace(/&#039;/gi, "\'");
        cleaned = cleaned.replace(/\[&#8230;\]/gi, "...");
        return cleaned;
    }

    public navigateToSources() {
        this.router.navigate(["sources"]);
    }

    public open(item: any) {
        Utility.openUrl(item.link);
    }

}